@@ -45,9 +45,11 @@ nice_assumptions <- function(model) {
     format(x$terms)
   })
   shapiro <- lapply(models.list, function(x) {
-    if(length(x$residuals) > 5000 || length(x$residuals) < 4) {
-      message("Sample size must be between 4 and 5000 for shapiro.test(); ",
-              "returning NA.")
+    if (length(x$residuals) > 5000 || length(x$residuals) < 4) {
+      message(
+        "Sample size must be between 4 and 5000 for shapiro.test(); ",
+        "returning NA."
+      )
       return(NA)
     }
     stats::shapiro.test(x$residuals)$p.value
@@ -66,7 +68,7 @@ nice_assumptions <- function(model) {
 
   names(df) <- c("Model", "shapiro", "bp", "dw")
   df <- df %>%
-    dplyr::mutate(dplyr::across(where(is.numeric), \(x) round(x, 3)),
+    dplyr::mutate(dplyr::across(where(is.numeric), function(x) round(x, 3)),
       Diagnostic = rowSums(dplyr::select(., shapiro:dw) < .05, na.rm = TRUE)
     )
 
