@@ -66,8 +66,9 @@ nice_lm_slopes <- function(model,
                            ci.alternative = "two.sided",
                            ...) {
   rlang::check_installed("effectsize",
-                         version = get_dep_version("effectsize"),
-                         reason = "for this function.")
+    version = get_dep_version("effectsize"),
+    reason = "for this function."
+  )
   if (inherits(model, "list") && all(unlist(lapply(model, inherits, "lm")))) {
     models.list <- model
   } else if (inherits(model, "lm")) {
